==> estateplat-common-1.2.1-20170407.021712-3-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSjcl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 不动产登记项目收件材料
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sjcl")
public class BdcSjcl implements Serializable {
    @Id
    private String sjclid;//收件材料id

    private String sjxxid;//不动产登记项目收件信息Id

    private String clmc;//材料名称

    private int fs;//份数

    private int xh;//序号

    private String cllx;//材料类型

    private Integer mrfs;//默认份数

    private Integer sfsjsy;//是否收缴收验

    private Integer sfewsj;//是否额外收件

    private Integer sfbcsj;//是否补充收件

    private Integer ys;//页数

    private String bz;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/15
     * @description 文件中心对应的NodeId
     */
    private Integer wjzxid;

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public Integer getMrfs() {
        return mrfs;
    }

    public void setMrfs(Integer mrfs) {
        this.mrfs = mrfs;
    }

    public Integer getSfsjsy() {
        return sfsjsy;
    }

    public void setSfsjsy(Integer sfsjsy) {
        this.sfsjsy = sfsjsy;
    }

    public Integer getSfewsj() {
        return sfewsj;
    }

    public void setSfewsj(Integer sfewsj) {
        this.sfewsj = sfewsj;
    }

    public Integer getSfbcsj() {
        return sfbcsj;
    }

    public void setSfbcsj(Integer sfbcsj) {
        this.sfbcsj = sfbcsj;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getSjxxid() {
        return sjxxid;
    }

    public void setSjxxid(String sjxxid) {
        this.sjxxid = sjxxid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public int getFs() {
        return fs;
    }

    public void setFs(int fs) {
        this.fs = fs;
    }

    public int getXh() {
        return xh;
    }

    public void setXh(int xh) {
        this.xh = xh;
    }

    public Integer getWjzxid() {
        return wjzxid;
    }

    public void setWjzxid(Integer wjzxid) {
        this.wjzxid = wjzxid;
    }
}

==> estateplat-common-1.2.1-20170628.073448-46-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSjcl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 不动产登记项目收件材料
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_sjcl")
public class BdcSjcl implements Serializable {
    @Id
    private String sjclid;//收件材料id

    private String sjxxid;//不动产登记项目收件信息Id

    private String clmc;//材料名称

    private int fs;//份数

    private int xh;//序号

    private String cllx;//材料类型

    private Integer mrfs;//默认份数

    private Integer sfsjsy;//是否收缴收验

    private Integer sfewsj;//是否额外收件

    private Integer sfbcsj;//是否补充收件

    private Integer ys;//页数

    private String bz;

    private Date clrq;//材料日期

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/15
     * @description 文件中心对应的NodeId
     */
    private Integer wjzxid;

    public String getCllx() {
        return cllx;
    }

    public void setCllx(String cllx) {
        this.cllx = cllx;
    }

    public Integer getMrfs() {
        return mrfs;
    }

    public void setMrfs(Integer mrfs) {
        this.mrfs = mrfs;
    }

    public Integer getSfsjsy() {
        return sfsjsy;
    }

    public void setSfsjsy(Integer sfsjsy) {
        this.sfsjsy = sfsjsy;
    }

    public Integer getSfewsj() {
        return sfewsj;
    }

    public void setSfewsj(Integer sfewsj) {
        this.sfewsj = sfewsj;
    }

    public Integer getSfbcsj() {
        return sfbcsj;
    }

    public void setSfbcsj(Integer sfbcsj) {
        this.sfbcsj = sfbcsj;
    }

    public Integer getYs() {
        return ys;
    }

    public void setYs(Integer ys) {
        this.ys = ys;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSjclid() {
        return sjclid;
    }

    public void setSjclid(String sjclid) {
        this.sjclid = sjclid;
    }

    public String getSjxxid() {
        return sjxxid;
    }

    public void setSjxxid(String sjxxid) {
        this.sjxxid = sjxxid;
    }

    public String getClmc() {
        return clmc;
    }

    public void setClmc(String clmc) {
        this.clmc = clmc;
    }

    public int getFs() {
        return fs;
    }

    public void setFs(int fs) {
        this.fs = fs;
    }

    public int getXh() {
        return xh;
    }

    public void setXh(int xh) {
        this.xh = xh;
    }

    public Integer getWjzxid() {
        return wjzxid;
    }

    public void setWjzxid(Integer wjzxid) {
        this.wjzxid = wjzxid;
    }

    public Date getClrq() {
        return clrq;
    }

    public void setClrq(Date clrq) {
        this.clrq = clrq;
    }
}
